Crate opcua_core

Crate opcua_core 

The OPC UA Core module holds functionality that is common to server and clients that make use of OPC UA. It contains message chunking, cryptography / pki, communications and standard handshake messages.

Re-exports

pub use messages::Message;
pub use messages::MessageType;
pub use messages::RequestMessage;
pub use messages::ResponseMessage;
pub use tracing;

Modules

comms
Contains all code related to sending / receiving messages from a transport and turning those messages into and out of chunks.
config
Common utilities for configuration files in both the server and client.
constants
Contains common OPC-UA constants.
debug
Contains debugging utility helper functions
handle
Utility for producing sequential message handles.
messages
RequestMessage and ResponseMessage, and utilities for working with these.
sync
Common synchronous locks. Re-exports locks from parking_lot used internally.

Macros

trace_lock
Tracing macro for obtaining a lock on a Mutex. Sometimes deadlocks can happen in code, and if they do, this macro is useful for finding out where they happened.
trace_read_lock
Tracing macro for obtaining a read lock on a RwLock.
trace_write_lock
Tracing macro for obtaining a write lock on a RwLock.

Functions

trace_locks
Check for the environment variable OPCUA_TRACE_LOCKS. If it is set to 1 or true, then tracing will be enabled for locks. This is useful for debugging deadlocks.